@@ -1,6 +1,7 @@
-from .src import initializeEnvironment
-ENV = initializeEnvironment()
+from .src import *
+
 def decode_event(data,**kwargs):
+    ENV = get_decoder_env()
     event = kwargs.get("event")
     discriminator = kwargs.get("discriminator")
     signature=kwargs.get("signature")
